ThreadView

Struct ThreadView 

pub struct ThreadView {
    pub roots: Vec<ThreadNode>,
    /* private fields */
}
Represents a collection of threaded conversations.

Fields

roots: Vec<ThreadNode>

Root posts (posts that are not replies to anything)

Implementations

Source

impl ThreadView

pub fn from_feed(feed: &Feed) -> Self

Create a threaded view from a Feed.

pub fn sort_threads(&mut self)

Sort all threads and their replies chronologically.

pub fn thread_count(&self) -> usize

pub fn total_posts(&self) -> usize

pub fn flatten(&self) -> Vec<&Rc<RefCell<Post>>>

pub fn is_empty(&self) -> bool

pub fn update_poll_node(&self, post_node: &ThreadNode, poll: &mut Poll)

pub fn add_post(&mut self, post: Rc<RefCell<Post>>)

Add a new post to the thread tree.

If the post is a reply, it will be added to the appropriate parent node. If the parent doesn’t exist, a placeholder will be created. If it’s not a reply, it will be added as a new root thread.

After adding the post, latest activity times will be updated and threads will be re-sorted.

Arguments
  • post - The new post to add to the thread tree